/*

Copyright 2012 Adam Reichold

This file is part of qpdfview.

qpdfview is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

qpdfview is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with qpdfview.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "miscellaneous.h"
#include "mainwindow.h"

int main(int argc, char *argv[])
{
    QApplication application(argc, argv);

    QApplication::setOrganizationName("qpdfview");
    QApplication::setApplicationName("qpdfview");

#ifdef DATA_INSTALL_PATH

    QString dataInstallPath(DATA_INSTALL_PATH);

    QApplication::setWindowIcon(QIcon(dataInstallPath + "/qpdfview.svg"));

    QTranslator translator;
    if(translator.load(QString(dataInstallPath + "/qpdfview_") + QLocale::system().name()))
    {
        application.installTranslator(&translator);
    }

#else

    QApplication::setWindowIcon(QIcon(":/icons/qpdfview.svg"));

    QTranslator translator;
    if(t.load(QString(":/translations/qpdfview_") + QLocale::system().name()))
    {
        application.installTranslator(&translator);
    }

#endif

    UniqueApplication *uniqueApplication = 0;
    MainWindow *mainWindow = 0;

    // command-line arguments

    QStringList arguments = QApplication::arguments();

    if(!arguments.isEmpty())
    {
        arguments.removeFirst();
    }

    if(arguments.contains("--unique"))
    {
        arguments.removeAll("--unique");

        uniqueApplication = new UniqueApplication("qpdfview", &application);

        if(uniqueApplication->isRunning())
        {
            foreach(QString argument, arguments)
            {
                uniqueApplication->sendMessage(argument);
            }

            return 0;
        }
        else
        {
            mainWindow = new MainWindow();

            QObject::connect(uniqueApplication, SIGNAL(messageReceived(QString)), mainWindow, SLOT(slotMessageReceived(QString)));
        }
    }
    else
    {
        mainWindow = new MainWindow();
    }

    foreach(QString argument, arguments)
    {
        QString filePath;
        int page = 1;
        float top = 0.0;

        QStringList fields = argument.split('#');

        filePath = fields.at(0);

        if(fields.count() > 1)
        {
            page = fields.at(1).toInt();

            page = page >= 1 ? page : 1;
        }

        if(fields.count() > 2)
        {
            top = fields.at(2).toFloat();

            top = top >= 0.0 ? top : 0.0;
            top = top <= 1.0 ? top : 1.0;
        }

        if(QFileInfo(filePath).exists())
        {
            mainWindow->addTab(filePath, page, top);
        }
    }

    mainWindow->show();

    mainWindow->setAttribute(Qt::WA_DeleteOnClose);

    return application.exec();
}
